@@ -25,7 +25,7 @@ with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "glib-compat.h"
 #include "dbus-test.h"
 
-struct _DbusTestBustlePrivate {
+typedef struct {
 	gchar * filename;
 	gchar * executable;
 
@@ -35,10 +35,7 @@ struct _DbusTestBustlePrivate {
 	GPid pid;
 
 	gboolean crashed;
-};
-
-#define DBUS_TEST_BUSTLE_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE ((o), DBUS_TEST_TYPE_BUSTLE, DbusTestBustlePrivate))
+} DbusTestBustlePrivate;
 
 static void dbus_test_bustle_class_init (DbusTestBustleClass *klass);
 static void dbus_test_bustle_init       (DbusTestBustle *self);
@@ -51,15 +48,13 @@ static gboolean bustle_write_error      (GIOChannel *          channel,
                                          GIOCondition          condition,
                                          gpointer              data);
 
-G_DEFINE_TYPE (DbusTestBustle, dbus_test_bustle, DBUS_TEST_TYPE_TASK);
+G_DEFINE_TYPE_WITH_PRIVATE (DbusTestBustle, dbus_test_bustle, DBUS_TEST_TYPE_TASK);
 
 static void
 dbus_test_bustle_class_init (DbusTestBustleClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (DbusTestBustlePrivate));
-
 	object_class->dispose = dbus_test_bustle_dispose;
 	object_class->finalize = dbus_test_bustle_finalize;
 
@@ -75,18 +70,21 @@ dbus_test_bustle_class_init (DbusTestBustleClass *klass)
 static void
 dbus_test_bustle_init (DbusTestBustle *self)
 {
-	self->priv = DBUS_TEST_BUSTLE_GET_PRIVATE(self);
+	gchar * current_dir = g_get_current_dir();
 
-	self->priv->filename = g_strconcat(g_get_current_dir(), G_DIR_SEPARATOR_S, "bustle.log", NULL);
-	self->priv->executable = g_strdup(BUSTLE_DUAL_MONITOR);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(self);
 
-	self->priv->watch = 0;
-	self->priv->stderr = NULL;
-	self->priv->file = NULL;
-	self->priv->pid = 0;
+	priv->filename = g_strconcat(current_dir, G_DIR_SEPARATOR_S, "bustle.log", NULL);
+	priv->executable = g_strdup(BUSTLE_DUAL_MONITOR);
 
-	self->priv->crashed = FALSE;
+	priv->watch = 0;
+	priv->stderr = NULL;
+	priv->file = NULL;
+	priv->pid = 0;
 
+	priv->crashed = FALSE;
+
+	g_free (current_dir);
 	return;
 }
 
@@ -95,31 +93,32 @@ dbus_test_bustle_dispose (GObject *object)
 {
 	g_return_if_fail(DBUS_TEST_IS_BUSTLE(object));
 	DbusTestBustle * bustler = DBUS_TEST_BUSTLE(object);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustler);
 
-	if (bustler->priv->watch != 0) {
-		g_source_remove(bustler->priv->watch);
-		bustler->priv->watch = 0;
+	if (priv->watch != 0) {
+		g_source_remove(priv->watch);
+		priv->watch = 0;
 	}
 
-	if (bustler->priv->pid != 0) {
-		gchar * command = g_strdup_printf("kill -INT %d", bustler->priv->pid);
+	if (priv->pid != 0) {
+		gchar * command = g_strdup_printf("kill -INT %d", priv->pid);
 		g_spawn_command_line_sync(command, NULL, NULL, NULL, NULL);
 		g_free(command);
 
-		g_spawn_close_pid(bustler->priv->pid);
+		g_spawn_close_pid(priv->pid);
 	}
 
-	if (bustler->priv->stderr != NULL) {
-		while (G_IO_IN & g_io_channel_get_buffer_condition(bustler->priv->stderr)) {
-			bustle_write_error(bustler->priv->stderr, 0 /* unused */, bustler);
+	if (priv->stderr != NULL) {
+		while (G_IO_IN & g_io_channel_get_buffer_condition(priv->stderr)) {
+			bustle_write_error(priv->stderr, 0 /* unused */, bustler);
 		}
 
-		g_clear_pointer(&bustler->priv->stderr, g_io_channel_unref);
+		g_clear_pointer(&priv->stderr, g_io_channel_unref);
 	}
 
-	if (bustler->priv->file != NULL) {
-		g_io_channel_shutdown(bustler->priv->file, TRUE, NULL);
-		g_clear_pointer(&bustler->priv->file, g_io_channel_unref);
+	if (priv->file != NULL) {
+		g_io_channel_shutdown(priv->file, TRUE, NULL);
+		g_clear_pointer(&priv->file, g_io_channel_unref);
 	}
 
 	G_OBJECT_CLASS (dbus_test_bustle_parent_class)->dispose (object);
@@ -131,9 +130,10 @@ dbus_test_bustle_finalize (GObject *object)
 {
 	g_return_if_fail(DBUS_TEST_IS_BUSTLE(object));
 	DbusTestBustle * bustler = DBUS_TEST_BUSTLE(object);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustler);
 
-	g_free(bustler->priv->filename);
-	g_free(bustler->priv->executable);
+	g_free(priv->filename);
+	g_free(priv->executable);
 
 	G_OBJECT_CLASS (dbus_test_bustle_parent_class)->finalize (object);
 	return;
@@ -146,9 +146,10 @@ dbus_test_bustle_new (const gchar * filename)
 
 	DbusTestBustle * bustler = g_object_new(DBUS_TEST_TYPE_BUSTLE,
 	                                        NULL);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustler);
 
-	g_free(bustler->priv->filename);
-	bustler->priv->filename = g_strdup(filename);
+	g_free(priv->filename);
+	priv->filename = g_strdup(filename);
 
 	dbus_test_task_set_name(DBUS_TEST_TASK(bustler), "Bustle");
 
@@ -161,8 +162,9 @@ dbus_test_bustle_set_executable (DbusTestBustle * bustle, const gchar * executab
 	g_return_if_fail(DBUS_TEST_IS_BUSTLE(bustle));
 	g_return_if_fail(executable != NULL);
 
-	g_free(bustle->priv->executable);
-	bustle->priv->executable = g_strdup(executable);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustle);
+	g_free(priv->executable);
+	priv->executable = g_strdup(executable);
 
 	return;
 }
@@ -172,13 +174,14 @@ bustle_watcher (GPid pid, G_GNUC_UNUSED gint status, gpointer data)
 {
 	g_critical("Bustle Monitor exited abruptly!");
 	DbusTestBustle * bustler = DBUS_TEST_BUSTLE(data);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustler);
 
-	if (bustler->priv->pid != 0) {
+	if (priv->pid != 0) {
 		g_spawn_close_pid(pid);
-		bustler->priv->pid = 0;
+		priv->pid = 0;
 	}
 
-	bustler->priv->crashed = TRUE;
+	priv->crashed = TRUE;
 	g_signal_emit_by_name(G_OBJECT(bustler), DBUS_TEST_TASK_SIGNAL_STATE_CHANGED, DBUS_TEST_TASK_STATE_FINISHED, NULL);
 
 	return;
@@ -215,62 +218,68 @@ process_run (DbusTestTask * task)
 {
 	g_return_if_fail(DBUS_TEST_IS_BUSTLE(task));
 	DbusTestBustle * bustler = DBUS_TEST_BUSTLE(task);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustler);
 
-	if (bustler->priv->pid != 0) {
+	if (priv->pid != 0) {
 		return;
 	}
 	
 	GError * error = NULL;
 
-	bustler->priv->file = g_io_channel_new_file(bustler->priv->filename, "w", &error);
+	priv->file = g_io_channel_new_file(priv->filename, "w", &error);
 
 	if (error != NULL) {
-		g_critical("Unable to open bustle file '%s': %s", bustler->priv->filename, error->message);
+		g_critical("Unable to open bustle file '%s': %s", priv->filename, error->message);
 		g_error_free(error);
 
-		bustler->priv->crashed = TRUE;
+		priv->crashed = TRUE;
 		g_signal_emit_by_name(G_OBJECT(bustler), DBUS_TEST_TASK_SIGNAL_STATE_CHANGED, DBUS_TEST_TASK_STATE_FINISHED, NULL);
 		return;
 	}
 
 	gint bustle_stderr_num;
+
+	gchar * current_dir = g_get_current_dir();
 	
 	gchar ** bustle_monitor = g_new0(gchar *, 3);
-	bustle_monitor[0] = (gchar *)bustler->priv->executable;
-	bustle_monitor[1] = (gchar *)bustler->priv->filename;
+	bustle_monitor[0] = (gchar *)priv->executable;
+	bustle_monitor[1] = (gchar *)priv->filename;
 
-	g_spawn_async_with_pipes(g_get_current_dir(),
+	g_spawn_async_with_pipes(current_dir,
 	                         bustle_monitor, /* argv */
 	                         NULL, /* envp */
 	                         /* G_SPAWN_SEARCH_PATH | G_SPAWN_STDERR_TO_DEV_NULL, */ /* flags */
 	                         G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD, /* flags */
 	                         NULL, /* child setup func */
 	                         NULL, /* child setup data */
-	                         &bustler->priv->pid, /* PID */
+	                         &priv->pid, /* PID */
 	                         NULL, /* stdin */
 	                         NULL, /* stdout */
 	                         &bustle_stderr_num, /* stderr */
 	                         &error); /* error */
 
+	g_free(current_dir);
+	g_free(bustle_monitor);
+
 	if (error != NULL) {
 		g_critical("Unable to start bustling data: %s", error->message);
 		g_error_free(error);
 
-		bustler->priv->pid = 0; /* ensure this */
-		bustler->priv->crashed = TRUE;
+		priv->pid = 0; /* ensure this */
+		priv->crashed = TRUE;
 		g_signal_emit_by_name(G_OBJECT(bustler), DBUS_TEST_TASK_SIGNAL_STATE_CHANGED, DBUS_TEST_TASK_STATE_FINISHED, NULL);
 		return;
 	}
 
 	if (TRUE) {
-		gchar * start = g_strdup_printf("Starting bustle monitor.  PID: %d", bustler->priv->pid);
+		gchar * start = g_strdup_printf("Starting bustle monitor.  PID: %d", priv->pid);
 		dbus_test_task_print(DBUS_TEST_TASK(bustler), start);
 		g_free(start);
 	}
-	bustler->priv->watch = g_child_watch_add(bustler->priv->pid, bustle_watcher, bustler);
+	priv->watch = g_child_watch_add(priv->pid, bustle_watcher, bustler);
 
-	bustler->priv->stderr = g_io_channel_unix_new(bustle_stderr_num);
-	g_io_add_watch(bustler->priv->stderr,
+	priv->stderr = g_io_channel_unix_new(bustle_stderr_num);
+	g_io_add_watch(priv->stderr,
 	               G_IO_IN | G_IO_HUP | G_IO_ERR, /* conditions */
 	               bustle_write_error, /* func */
 	               bustler); /* func data */
@@ -291,11 +300,11 @@ get_passed (DbusTestTask * task)
 {
 	g_return_val_if_fail(DBUS_TEST_IS_BUSTLE(task), FALSE);
 	DbusTestBustle * bustler = DBUS_TEST_BUSTLE(task);
+	DbusTestBustlePrivate *priv = dbus_test_bustle_get_instance_private(bustler);
 
-	if (bustler->priv->crashed) {
+	if (priv->crashed) {
 		return FALSE;
 	} else {
 		return TRUE;
 	}
 }
-
