@@ -35,7 +35,6 @@ G_BEGIN_DECLS
 
 typedef struct _DbusTestProcess         DbusTestProcess;
 typedef struct _DbusTestProcessClass    DbusTestProcessClass;
-typedef struct _DbusTestProcessPrivate  DbusTestProcessPrivate;
 
 struct _DbusTestProcessClass {
 	DbusTestTaskClass parent_class;
@@ -43,7 +42,6 @@ struct _DbusTestProcessClass {
 
 struct _DbusTestProcess {
 	DbusTestTask parent;
-	DbusTestProcessPrivate * priv;
 };
 
 GType dbus_test_process_get_type (void);
