@@ -43,7 +43,7 @@ enum _ServiceState {
 	STATE_FINISHED
 };
 
-struct _DbusTestServicePrivate {
+typedef struct {
 	GQueue tasks_first;
 	GQueue tasks_normal;
 	GQueue tasks_last;
@@ -67,28 +67,23 @@ struct _DbusTestServicePrivate {
 	guint watchdog_source;
 
 	DbusTestServiceBus bus_type;
-};
+} DbusTestServicePrivate;
 
 #define SERVICE_CHANGE_HANDLER  "dbus-test-service-change-handler"
 
-#define DBUS_TEST_SERVICE_GET_PRIVATE(o) \
-(G_TYPE_INSTANCE_GET_PRIVATE ((o), DBUS_TEST_TYPE_SERVICE, DbusTestServicePrivate))
-
 static void dbus_test_service_class_init (DbusTestServiceClass *klass);
 static void dbus_test_service_init       (DbusTestService *self);
 static void dbus_test_service_dispose    (GObject *object);
 static void dbus_test_service_finalize   (GObject *object);
 static gboolean watchdog_ping            (gpointer user_data);
 
-G_DEFINE_TYPE (DbusTestService, dbus_test_service, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (DbusTestService, dbus_test_service, G_TYPE_OBJECT);
 
 static void
 dbus_test_service_class_init (DbusTestServiceClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (DbusTestServicePrivate));
-
 	object_class->dispose = dbus_test_service_dispose;
 	object_class->finalize = dbus_test_service_finalize;
 
@@ -98,35 +93,35 @@ dbus_test_service_class_init (DbusTestServiceClass *klass)
 static void
 dbus_test_service_init (DbusTestService *self)
 {
-	self->priv = DBUS_TEST_SERVICE_GET_PRIVATE(self);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(self);
 
-	g_queue_init(&self->priv->tasks_first);
-	g_queue_init(&self->priv->tasks_normal);
-	g_queue_init(&self->priv->tasks_last);
+	g_queue_init(&priv->tasks_first);
+	g_queue_init(&priv->tasks_normal);
+	g_queue_init(&priv->tasks_last);
 
-	self->priv->mainloop = g_main_loop_new(NULL, FALSE);
-	self->priv->state = STATE_INIT;
+	priv->mainloop = g_main_loop_new(NULL, FALSE);
+	priv->state = STATE_INIT;
 
-	self->priv->daemon_crashed = FALSE;
+	priv->daemon_crashed = FALSE;
 
-	self->priv->dbus = 0;
-	self->priv->dbus_watch = 0;
-	self->priv->dbus_io = NULL;
-	self->priv->dbus_io_watch = 0;
-	self->priv->dbus_daemon = g_strdup("dbus-daemon");
-	self->priv->dbus_configfile = g_strdup(DEFAULT_SESSION_CONF);
+	priv->dbus = 0;
+	priv->dbus_watch = 0;
+	priv->dbus_io = NULL;
+	priv->dbus_io_watch = 0;
+	priv->dbus_daemon = g_strdup("dbus-daemon");
+	priv->dbus_configfile = g_strdup(DEFAULT_SESSION_CONF);
 
-	self->priv->first_time = TRUE;
-	self->priv->keep_env = FALSE;
+	priv->first_time = TRUE;
+	priv->keep_env = FALSE;
 
-	self->priv->watchdog = g_object_new(DBUS_TEST_TYPE_WATCHDOG, NULL);
-	self->priv->watchdog_source = g_timeout_add_seconds_full(G_PRIORITY_DEFAULT,
+	priv->watchdog = g_object_new(DBUS_TEST_TYPE_WATCHDOG, NULL);
+	priv->watchdog_source = g_timeout_add_seconds_full(G_PRIORITY_DEFAULT,
 	                                                         5,
 	                                                         watchdog_ping,
-	                                                         g_object_ref(self->priv->watchdog),
+	                                                         g_object_ref(priv->watchdog),
 	                                                         g_object_unref);
 
-	self->priv->bus_type = DBUS_TEST_SERVICE_BUS_SESSION;
+	priv->bus_type = DBUS_TEST_SERVICE_BUS_SESSION;
 
 	return;
 }
@@ -150,58 +145,59 @@ dbus_test_service_dispose (GObject *object)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(object));
 	DbusTestService * self = DBUS_TEST_SERVICE(object);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(self);
 
-	if (!g_queue_is_empty(&self->priv->tasks_last)) {
-		g_queue_foreach(&self->priv->tasks_last, task_unref, NULL);
-		g_queue_clear(&self->priv->tasks_last);
+	if (!g_queue_is_empty(&priv->tasks_last)) {
+		g_queue_foreach(&priv->tasks_last, task_unref, NULL);
+		g_queue_clear(&priv->tasks_last);
 	}
 
-	if (!g_queue_is_empty(&self->priv->tasks_normal)) {
-		g_queue_foreach(&self->priv->tasks_normal, task_unref, NULL);
-		g_queue_clear(&self->priv->tasks_normal);
+	if (!g_queue_is_empty(&priv->tasks_normal)) {
+		g_queue_foreach(&priv->tasks_normal, task_unref, NULL);
+		g_queue_clear(&priv->tasks_normal);
 	}
 
-	if (!g_queue_is_empty(&self->priv->tasks_first)) {
-		g_queue_foreach(&self->priv->tasks_first, task_unref, NULL);
-		g_queue_clear(&self->priv->tasks_first);
+	if (!g_queue_is_empty(&priv->tasks_first)) {
+		g_queue_foreach(&priv->tasks_first, task_unref, NULL);
+		g_queue_clear(&priv->tasks_first);
 	}
 
-	if (self->priv->dbus_watch != 0) {
-		g_source_remove(self->priv->dbus_watch);
-		self->priv->dbus_watch = 0;
+	if (priv->dbus_watch != 0) {
+		g_source_remove(priv->dbus_watch);
+		priv->dbus_watch = 0;
 	}
 
-	if (self->priv->dbus_io_watch != 0) {
-		g_source_remove(self->priv->dbus_io_watch);
-		self->priv->dbus_io_watch = 0;
+	if (priv->dbus_io_watch != 0) {
+		g_source_remove(priv->dbus_io_watch);
+		priv->dbus_io_watch = 0;
 	}
 
-	if (self->priv->dbus_io != NULL) {
-		g_io_channel_shutdown(self->priv->dbus_io, TRUE, NULL);
-		g_io_channel_unref(self->priv->dbus_io);
-		self->priv->dbus_io = NULL;
+	if (priv->dbus_io != NULL) {
+		g_io_channel_shutdown(priv->dbus_io, TRUE, NULL);
+		g_io_channel_unref(priv->dbus_io);
+		priv->dbus_io = NULL;
 	}
 
 	g_print("DBus daemon: Shutdown\n");
-	if (self->priv->dbus != 0) {
-		gchar * cmd = g_strdup_printf("kill -9 %d", self->priv->dbus);
+	if (priv->dbus != 0) {
+		gchar * cmd = g_strdup_printf("kill -9 %d", priv->dbus);
 		g_spawn_command_line_async(cmd, NULL);
 		g_free(cmd);
 
-		g_spawn_close_pid(self->priv->dbus);
-		self->priv->dbus = 0;
+		g_spawn_close_pid(priv->dbus);
+		priv->dbus = 0;
 	}
 
-	if (self->priv->mainloop != NULL) {
-		g_main_loop_unref(self->priv->mainloop);
-		self->priv->mainloop = NULL;
+	if (priv->mainloop != NULL) {
+		g_main_loop_unref(priv->mainloop);
+		priv->mainloop = NULL;
 	}
 
-	g_clear_object(&self->priv->watchdog);
+	g_clear_object(&priv->watchdog);
 
-	if (self->priv->watchdog_source != 0) {
-		g_source_remove(self->priv->watchdog_source);
-		self->priv->watchdog_source = 0;
+	if (priv->watchdog_source != 0) {
+		g_source_remove(priv->watchdog_source);
+		priv->watchdog_source = 0;
 	}
 
 	G_OBJECT_CLASS (dbus_test_service_parent_class)->dispose (object);
@@ -213,11 +209,12 @@ dbus_test_service_finalize (GObject *object)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(object));
 	DbusTestService * self = DBUS_TEST_SERVICE(object);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(self);
 
-	g_free(self->priv->dbus_daemon);
-	self->priv->dbus_daemon = NULL;
-	g_free(self->priv->dbus_configfile);
-	self->priv->dbus_configfile = NULL;
+	g_free(priv->dbus_daemon);
+	priv->dbus_daemon = NULL;
+	g_free(priv->dbus_configfile);
+	priv->dbus_configfile = NULL;
 
 	G_OBJECT_CLASS (dbus_test_service_parent_class)->finalize (object);
 	return;
@@ -273,9 +270,11 @@ all_tasks_started_helper (G_GNUC_UNUSED DbusTestService * service, DbusTestTask
 static gboolean
 all_tasks_bus_match (DbusTestService * service, DbusTestTask * task, G_GNUC_UNUSED gpointer user_data)
 {
-	return service->priv->bus_type == DBUS_TEST_SERVICE_BUS_BOTH ||
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	return priv->bus_type == DBUS_TEST_SERVICE_BUS_BOTH ||
 		dbus_test_task_get_bus(task) == DBUS_TEST_SERVICE_BUS_BOTH ||
-		dbus_test_task_get_bus(task) == service->priv->bus_type;
+		dbus_test_task_get_bus(task) == priv->bus_type;
 }
 
 typedef struct {
@@ -301,6 +300,8 @@ all_tasks_helper (gpointer taskp, gpointer datap)
 static gboolean
 all_tasks (DbusTestService * service, gboolean (*helper) (DbusTestService * service, DbusTestTask * task, gpointer user_data), gpointer user_data)
 {
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
 	all_tasks_helper_data_t data = {
 		.passing = TRUE,
 		.service = service,
@@ -308,17 +309,17 @@ all_tasks (DbusTestService * service, gboolean (*helper) (DbusTestService * serv
 		.user_data = user_data
 	};
 
-	g_queue_foreach(&service->priv->tasks_first, all_tasks_helper, &data);
+	g_queue_foreach(&priv->tasks_first, all_tasks_helper, &data);
 	if (!data.passing) {
 		return FALSE;
 	}
 
-	g_queue_foreach(&service->priv->tasks_normal, all_tasks_helper, &data);
+	g_queue_foreach(&priv->tasks_normal, all_tasks_helper, &data);
 	if (!data.passing) {
 		return FALSE;
 	}
 
-	g_queue_foreach(&service->priv->tasks_last, all_tasks_helper, &data);
+	g_queue_foreach(&priv->tasks_last, all_tasks_helper, &data);
 	if (!data.passing) {
 		return FALSE;
 	}
@@ -356,13 +357,15 @@ normalize_name_lengths (DbusTestService * service)
 {
 	glong length = 0;
 
-	g_queue_foreach(&service->priv->tasks_first, task_get_name_length, &length);
-	g_queue_foreach(&service->priv->tasks_normal, task_get_name_length, &length);
-	g_queue_foreach(&service->priv->tasks_last, task_get_name_length, &length);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
 
-	g_queue_foreach(&service->priv->tasks_first, task_set_name_length, &length);
-	g_queue_foreach(&service->priv->tasks_normal, task_set_name_length, &length);
-	g_queue_foreach(&service->priv->tasks_last, task_set_name_length, &length);
+	g_queue_foreach(&priv->tasks_first, task_get_name_length, &length);
+	g_queue_foreach(&priv->tasks_normal, task_get_name_length, &length);
+	g_queue_foreach(&priv->tasks_last, task_get_name_length, &length);
+
+	g_queue_foreach(&priv->tasks_first, task_set_name_length, &length);
+	g_queue_foreach(&priv->tasks_normal, task_set_name_length, &length);
+	g_queue_foreach(&priv->tasks_last, task_set_name_length, &length);
 
 	return;
 }
@@ -381,6 +384,7 @@ static gboolean
 dbus_writes (GIOChannel * channel, GIOCondition condition, gpointer data)
 {
 	DbusTestService * service = DBUS_TEST_SERVICE(data);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
 
 	if (condition & G_IO_ERR) {
 		g_critical("DBus writing failure!");
@@ -395,12 +399,12 @@ dbus_writes (GIOChannel * channel, GIOCondition condition, gpointer data)
 
 	g_print("DBus daemon: %s\n", line);
 
-	if (service->priv->first_time) {
-		service->priv->first_time = FALSE;
+	if (priv->first_time) {
+		priv->first_time = FALSE;
 
 		g_setenv("DBUS_STARTER_ADDRESS", line, TRUE);
 
-		switch (service->priv->bus_type) {
+		switch (priv->bus_type) {
 		case DBUS_TEST_SERVICE_BUS_SESSION:
 			g_setenv("DBUS_SESSION_BUS_ADDRESS", line, TRUE);
 			g_setenv("DBUS_STARTER_BUS_TYPE", "session", TRUE);
@@ -416,8 +420,8 @@ dbus_writes (GIOChannel * channel, GIOCondition condition, gpointer data)
 			break;
 		}
 
-		if (service->priv->state == STATE_DAEMON_STARTING) {
-			g_main_loop_quit(service->priv->mainloop);
+		if (priv->state == STATE_DAEMON_STARTING) {
+			g_main_loop_quit(priv->mainloop);
 		}
 	}
 
@@ -430,10 +434,12 @@ static void
 dbus_watcher (GPid pid, G_GNUC_UNUSED gint status, gpointer data)
 {
 	DbusTestService * service = DBUS_TEST_SERVICE(data);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
 	g_critical("DBus Daemon exited abruptly!");
 
-	service->priv->daemon_crashed = TRUE;
-	g_main_loop_quit(DBUS_TEST_SERVICE(data)->priv->mainloop);
+	priv->daemon_crashed = TRUE;
+	g_main_loop_quit(priv->mainloop);
 
 	if (pid != 0) {
 		g_spawn_close_pid(pid);
@@ -451,24 +457,26 @@ dbus_child_setup ()
 static void
 start_daemon (DbusTestService * service)
 {
-	if (service->priv->dbus != 0) {
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	if (priv->dbus != 0) {
 		return;
 	}
 
-	service->priv->state = STATE_DAEMON_STARTING;
+	priv->state = STATE_DAEMON_STARTING;
 
 	gint dbus_stdout = 0;
 	GError * error = NULL;
 	gchar * blank[1] = {NULL};
 	gchar * current_dir = g_get_current_dir();
-	gchar * dbus_startup[] = {service->priv->dbus_daemon, "--config-file", service->priv->dbus_configfile, "--print-address", NULL};
+	gchar * dbus_startup[] = {priv->dbus_daemon, "--config-file", priv->dbus_configfile, "--print-address", NULL};
 	g_spawn_async_with_pipes(current_dir,
 	                         dbus_startup, /* argv */
-	                         service->priv->keep_env ? NULL : blank, /* envp */
+	                         priv->keep_env ? NULL : blank, /* envp */
 	                         G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD, /* flags */
 	                         (GSpawnChildSetupFunc) dbus_child_setup, /* child setup func */
 	                         NULL, /* child setup data */
-	                         &service->priv->dbus, /* PID */
+	                         &priv->dbus, /* PID */
 	                         NULL, /* stdin */
 	                         &dbus_stdout, /* stdout */
 	                         NULL, /* stderr */
@@ -479,25 +487,25 @@ start_daemon (DbusTestService * service)
 	if (error != NULL) {
 		g_critical("Unable to start dbus daemon: %s", error->message);
 		g_error_free(error);
-		service->priv->daemon_crashed = TRUE;
+		priv->daemon_crashed = TRUE;
 		return;
 	}
 
-	dbus_test_watchdog_add_pid(service->priv->watchdog, service->priv->dbus);
+	dbus_test_watchdog_add_pid(priv->watchdog, priv->dbus);
 
-	service->priv->dbus_watch = g_child_watch_add(service->priv->dbus, dbus_watcher, service);
+	priv->dbus_watch = g_child_watch_add(priv->dbus, dbus_watcher, service);
 
-	service->priv->dbus_io = g_io_channel_unix_new(dbus_stdout);
-	service->priv->dbus_io_watch = g_io_add_watch(service->priv->dbus_io,
+	priv->dbus_io = g_io_channel_unix_new(dbus_stdout);
+	priv->dbus_io_watch = g_io_add_watch(priv->dbus_io,
 	                                              G_IO_IN | G_IO_HUP | G_IO_ERR, /* conditions */
 	                                              dbus_writes, /* func */
 	                                              service); /* func data */
 
-	g_main_loop_run(service->priv->mainloop);
+	g_main_loop_run(priv->mainloop);
 
 	/* we should have a usable connection now, let's check */
 	const gchar * bus_address = NULL;
-	if (service->priv->bus_type == DBUS_TEST_SERVICE_BUS_SYSTEM) {
+	if (priv->bus_type == DBUS_TEST_SERVICE_BUS_SYSTEM) {
 		bus_address = g_getenv("DBUS_SYSTEM_BUS_ADDRESS");
 	} else {
 		bus_address = g_getenv("DBUS_SESSION_BUS_ADDRESS");
@@ -516,13 +524,13 @@ start_daemon (DbusTestService * service)
 	g_strfreev(tokens);
 
 	if (!is_valid) {
-		service->priv->state = STATE_DAEMON_FAILED;
+		priv->state = STATE_DAEMON_FAILED;
 		g_critical ("DBus daemon failed: Bus address is not supported");
 		g_error_free (error);
 		return;
 	}
 
-	service->priv->state = STATE_DAEMON_STARTED;
+	priv->state = STATE_DAEMON_STARTED;
 	return;
 }
 
@@ -532,43 +540,45 @@ dbus_test_service_start_tasks (DbusTestService * service)
 	g_return_if_fail(DBUS_TEST_SERVICE(service));
 	g_return_if_fail(all_tasks(service, all_tasks_bus_match, NULL));
 
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
 	start_daemon(service);
 	g_return_if_fail(g_getenv("DBUS_SESSION_BUS_ADDRESS") != NULL ||
 		g_getenv("DBUS_SYSTEM_BUS_ADDRESS") != NULL);
-	g_return_if_fail(service->priv->state != STATE_DAEMON_FAILED);
+	g_return_if_fail(priv->state != STATE_DAEMON_FAILED);
 
 	if (all_tasks(service, all_tasks_started_helper, NULL)) {
 		/* If we have all started we can mark it as such as long
 		   as we understand where we could hit this case */
-		if (service->priv->state == STATE_INIT || service->priv->state == STATE_DAEMON_STARTED) {
-			service->priv->state = STATE_STARTED;
+		if (priv->state == STATE_INIT || priv->state == STATE_DAEMON_STARTED) {
+			priv->state = STATE_STARTED;
 		}
 		return;
 	}
 
 	normalize_name_lengths(service);
 
-	g_queue_foreach(&service->priv->tasks_first, task_starter, NULL);
-	if (!g_queue_is_empty(&service->priv->tasks_first)) {
+	g_queue_foreach(&priv->tasks_first, task_starter, NULL);
+	if (!g_queue_is_empty(&priv->tasks_first)) {
 		g_usleep(100000);
 	}
 
-	g_queue_foreach(&service->priv->tasks_normal, task_starter, NULL);
+	g_queue_foreach(&priv->tasks_normal, task_starter, NULL);
 
-	if (!g_queue_is_empty(&service->priv->tasks_last)) {
+	if (!g_queue_is_empty(&priv->tasks_last)) {
 		g_usleep(100000);
 	}
-	g_queue_foreach(&service->priv->tasks_last, task_starter, NULL);
+	g_queue_foreach(&priv->tasks_last, task_starter, NULL);
 
 	if (!all_tasks(service, all_tasks_started_helper, NULL)) {
-		service->priv->state = STATE_STARTING;
-		g_main_loop_run(service->priv->mainloop);
+		priv->state = STATE_STARTING;
+		g_main_loop_run(priv->mainloop);
 
 		/* This should never happen, but let's be sure */
 		g_return_if_fail(all_tasks(service, all_tasks_started_helper, NULL));
 	}
 
-	service->priv->state = STATE_STARTED;
+	priv->state = STATE_STARTED;
 
 	return;
 }
@@ -582,7 +592,9 @@ all_tasks_passed_helper (G_GNUC_UNUSED DbusTestService * service, DbusTestTask *
 static int
 get_status (DbusTestService * service)
 {
-	if (service->priv->daemon_crashed || service->priv->state == STATE_DAEMON_FAILED) {
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	if (priv->daemon_crashed || priv->state == STATE_DAEMON_FAILED) {
 		return -1;
 	}
 
@@ -597,20 +609,21 @@ int
 dbus_test_service_run (DbusTestService * service)
 {
 	g_return_val_if_fail(DBUS_TEST_SERVICE(service), -1);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
 
 	dbus_test_service_start_tasks(service);
-	g_return_val_if_fail(service->priv->state == STATE_STARTED, get_status(service));
+	g_return_val_if_fail(priv->state == STATE_STARTED, get_status(service));
 
 	if (all_tasks(service, all_tasks_finished_helper, NULL)) {
 		return get_status(service);
 	}
 
-	service->priv->state = STATE_RUNNING;
-	g_main_loop_run(service->priv->mainloop);
+	priv->state = STATE_RUNNING;
+	g_main_loop_run(priv->mainloop);
 
 	/* This should never happen, but let's be sure */
 	g_return_val_if_fail(all_tasks(service, all_tasks_finished_helper, NULL), -1);
-	service->priv->state = STATE_FINISHED;
+	priv->state = STATE_FINISHED;
 
 	return get_status(service);
 }
@@ -620,14 +633,15 @@ task_state_changed (G_GNUC_UNUSED DbusTestTask * task, G_GNUC_UNUSED DbusTestTas
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(user_data));
 	DbusTestService * service = DBUS_TEST_SERVICE(user_data);
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
 
-	if (service->priv->state == STATE_STARTING && all_tasks(service, all_tasks_started_helper, NULL)) {
-		g_main_loop_quit(service->priv->mainloop);
+	if (priv->state == STATE_STARTING && all_tasks(service, all_tasks_started_helper, NULL)) {
+		g_main_loop_quit(priv->mainloop);
 		return;
 	}
 
-	if (service->priv->state == STATE_RUNNING && all_tasks(service, all_tasks_finished_helper, NULL)) {
-		g_main_loop_quit(service->priv->mainloop);
+	if (priv->state == STATE_RUNNING && all_tasks(service, all_tasks_finished_helper, NULL)) {
+		g_main_loop_quit(priv->mainloop);
 		return;
 	}
 
@@ -650,17 +664,19 @@ dbus_test_service_add_task_with_priority (DbusTestService * service, DbusTestTas
 	   goals for busness. Fail early. */
 	g_return_if_fail(all_tasks_bus_match(service, task, NULL));
 
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
 	GQueue * queue = NULL;
 
 	switch (prio) {
 	case DBUS_TEST_SERVICE_PRIORITY_FIRST:
-		queue = &service->priv->tasks_first;
+		queue = &priv->tasks_first;
 		break;
 	case DBUS_TEST_SERVICE_PRIORITY_NORMAL:
-		queue = &service->priv->tasks_normal;
+		queue = &priv->tasks_normal;
 		break;
 	case DBUS_TEST_SERVICE_PRIORITY_LAST:
-		queue = &service->priv->tasks_last;
+		queue = &priv->tasks_last;
 		break;
 	default:
 		g_assert_not_reached();
@@ -690,10 +706,12 @@ dbus_test_service_remove_task (DbusTestService * service, DbusTestTask * task)
 	g_return_val_if_fail(DBUS_TEST_IS_SERVICE(service), FALSE);
 	g_return_val_if_fail(DBUS_TEST_IS_TASK(task), FALSE);
 
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
 	guint count = 0;
-	count += g_queue_remove_all(&service->priv->tasks_first, task);
-	count += g_queue_remove_all(&service->priv->tasks_normal, task);
-	count += g_queue_remove_all(&service->priv->tasks_last, task);
+	count += g_queue_remove_all(&priv->tasks_first, task);
+	count += g_queue_remove_all(&priv->tasks_normal, task);
+	count += g_queue_remove_all(&priv->tasks_last, task);
 
 	/* Checking the count here so that we can generate a warning. Guessing that
 	   this actually never happens, but it's easy to check */
@@ -718,8 +736,11 @@ void
 dbus_test_service_set_daemon (DbusTestService * service, const gchar * daemon)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(service));
-	g_free(service->priv->dbus_daemon);
-	service->priv->dbus_daemon = g_strdup(daemon);
+
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	g_free(priv->dbus_daemon);
+	priv->dbus_daemon = g_strdup(daemon);
 	return;
 }
 
@@ -727,8 +748,11 @@ void
 dbus_test_service_set_conf_file (DbusTestService * service, const gchar * conffile)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(service));
-	g_free(service->priv->dbus_configfile);
-	service->priv->dbus_configfile = g_strdup(conffile);
+
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	g_free(priv->dbus_configfile);
+	priv->dbus_configfile = g_strdup(conffile);
 	return;
 }
 
@@ -736,35 +760,44 @@ void
 dbus_test_service_set_keep_environment (DbusTestService * service, gboolean keep_env)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(service));
-	service->priv->keep_env = keep_env;
+
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	priv->keep_env = keep_env;
 }
 
 void
 dbus_test_service_stop (DbusTestService * service)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(service));
-	g_main_loop_quit(service->priv->mainloop);
+
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	g_main_loop_quit(priv->mainloop);
 	return;
 }
 
 void dbus_test_service_set_bus (DbusTestService * service, DbusTestServiceBus bus)
 {
 	g_return_if_fail(DBUS_TEST_IS_SERVICE(service));
-	g_return_if_fail(service->priv->dbus == 0); /* we can't change after we're running */
+
+	DbusTestServicePrivate *priv = dbus_test_service_get_instance_private(service);
+
+	g_return_if_fail(priv->dbus == 0); /* we can't change after we're running */
 
 	if (bus == DBUS_TEST_SERVICE_BUS_BOTH) {
 		g_warning("Setting bus to BOTH, which is typically only used as a default value.");
 	}
 
-	service->priv->bus_type = bus;
+	priv->bus_type = bus;
 	g_warn_if_fail(all_tasks(service, all_tasks_bus_match, NULL));
 
 	if (bus == DBUS_TEST_SERVICE_BUS_SYSTEM) {
-		g_free(service->priv->dbus_configfile);
-		service->priv->dbus_configfile = g_strdup(DEFAULT_SYSTEM_CONF);
+		g_free(priv->dbus_configfile);
+		priv->dbus_configfile = g_strdup(DEFAULT_SYSTEM_CONF);
 	} else {
 		/* BOTH and SESSION get the session config — for backwards compatibility there */
-		g_free(service->priv->dbus_configfile);
-		service->priv->dbus_configfile = g_strdup(DEFAULT_SESSION_CONF);
+		g_free(priv->dbus_configfile);
+		priv->dbus_configfile = g_strdup(DEFAULT_SESSION_CONF);
 	}
 }
